# Generated from vhdlParser.g4 by ANTLR 4.8
from antlr4 import *
if __name__ is not None and "." in __name__:
    from .vhdlParser import vhdlParser
else:
    from vhdlParser import vhdlParser

# This class defines a complete generic visitor for a parse tree produced by vhdlParser.

class vhdlParserVisitor(ParseTreeVisitor):

    # Visit a parse tree produced by vhdlParser#any_keyword.
    def visitAny_keyword(self, ctx:vhdlParser.Any_keywordContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#name_literal.
    def visitName_literal(self, ctx:vhdlParser.Name_literalContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#name.
    def visitName(self, ctx:vhdlParser.NameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#name_slice_part.
    def visitName_slice_part(self, ctx:vhdlParser.Name_slice_partContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#name_attribute_part.
    def visitName_attribute_part(self, ctx:vhdlParser.Name_attribute_partContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#attribute_name.
    def visitAttribute_name(self, ctx:vhdlParser.Attribute_nameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#suffix.
    def visitSuffix(self, ctx:vhdlParser.SuffixContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#explicit_range.
    def visitExplicit_range(self, ctx:vhdlParser.Explicit_rangeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_name.
    def visitSelected_name(self, ctx:vhdlParser.Selected_nameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_declaration.
    def visitEntity_declaration(self, ctx:vhdlParser.Entity_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_declarative_item.
    def visitEntity_declarative_item(self, ctx:vhdlParser.Entity_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_statement.
    def visitEntity_statement(self, ctx:vhdlParser.Entity_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#architecture_body.
    def visitArchitecture_body(self, ctx:vhdlParser.Architecture_bodyContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#block_declarative_item.
    def visitBlock_declarative_item(self, ctx:vhdlParser.Block_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#configuration_declaration.
    def visitConfiguration_declaration(self, ctx:vhdlParser.Configuration_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#configuration_declarative_item.
    def visitConfiguration_declarative_item(self, ctx:vhdlParser.Configuration_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#block_configuration.
    def visitBlock_configuration(self, ctx:vhdlParser.Block_configurationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#block_specification.
    def visitBlock_specification(self, ctx:vhdlParser.Block_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generate_specification.
    def visitGenerate_specification(self, ctx:vhdlParser.Generate_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#configuration_item.
    def visitConfiguration_item(self, ctx:vhdlParser.Configuration_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#component_configuration.
    def visitComponent_configuration(self, ctx:vhdlParser.Component_configurationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subprogram_declaration.
    def visitSubprogram_declaration(self, ctx:vhdlParser.Subprogram_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subprogram_specification.
    def visitSubprogram_specification(self, ctx:vhdlParser.Subprogram_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#procedure_specification.
    def visitProcedure_specification(self, ctx:vhdlParser.Procedure_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#function_specification.
    def visitFunction_specification(self, ctx:vhdlParser.Function_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subprogram_header.
    def visitSubprogram_header(self, ctx:vhdlParser.Subprogram_headerContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#designator.
    def visitDesignator(self, ctx:vhdlParser.DesignatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#operator_symbol.
    def visitOperator_symbol(self, ctx:vhdlParser.Operator_symbolContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#formal_parameter_list.
    def visitFormal_parameter_list(self, ctx:vhdlParser.Formal_parameter_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subprogram_body.
    def visitSubprogram_body(self, ctx:vhdlParser.Subprogram_bodyContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subprogram_kind.
    def visitSubprogram_kind(self, ctx:vhdlParser.Subprogram_kindContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subprogram_instantiation_declaration.
    def visitSubprogram_instantiation_declaration(self, ctx:vhdlParser.Subprogram_instantiation_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#signature.
    def visitSignature(self, ctx:vhdlParser.SignatureContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#package_declaration.
    def visitPackage_declaration(self, ctx:vhdlParser.Package_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#package_declarative_item.
    def visitPackage_declarative_item(self, ctx:vhdlParser.Package_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#package_body.
    def visitPackage_body(self, ctx:vhdlParser.Package_bodyContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#package_instantiation_declaration.
    def visitPackage_instantiation_declaration(self, ctx:vhdlParser.Package_instantiation_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#scalar_type_definition.
    def visitScalar_type_definition(self, ctx:vhdlParser.Scalar_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#range_constraint.
    def visitRange_constraint(self, ctx:vhdlParser.Range_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#range_.
    def visitRange_(self, ctx:vhdlParser.Range_Context):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#direction.
    def visitDirection(self, ctx:vhdlParser.DirectionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#enumeration_type_definition.
    def visitEnumeration_type_definition(self, ctx:vhdlParser.Enumeration_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#enumeration_literal.
    def visitEnumeration_literal(self, ctx:vhdlParser.Enumeration_literalContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#integer_type_definition.
    def visitInteger_type_definition(self, ctx:vhdlParser.Integer_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#physical_type_definition.
    def visitPhysical_type_definition(self, ctx:vhdlParser.Physical_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#primary_unit_declaration.
    def visitPrimary_unit_declaration(self, ctx:vhdlParser.Primary_unit_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#secondary_unit_declaration.
    def visitSecondary_unit_declaration(self, ctx:vhdlParser.Secondary_unit_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#floating_type_definition.
    def visitFloating_type_definition(self, ctx:vhdlParser.Floating_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#composite_type_definition.
    def visitComposite_type_definition(self, ctx:vhdlParser.Composite_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#array_type_definition.
    def visitArray_type_definition(self, ctx:vhdlParser.Array_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#unbounded_array_definition.
    def visitUnbounded_array_definition(self, ctx:vhdlParser.Unbounded_array_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#constrained_array_definition.
    def visitConstrained_array_definition(self, ctx:vhdlParser.Constrained_array_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#index_subtype_definition.
    def visitIndex_subtype_definition(self, ctx:vhdlParser.Index_subtype_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#array_constraint.
    def visitArray_constraint(self, ctx:vhdlParser.Array_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#array_element_constraint.
    def visitArray_element_constraint(self, ctx:vhdlParser.Array_element_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#index_constraint.
    def visitIndex_constraint(self, ctx:vhdlParser.Index_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#discrete_range.
    def visitDiscrete_range(self, ctx:vhdlParser.Discrete_rangeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#record_type_definition.
    def visitRecord_type_definition(self, ctx:vhdlParser.Record_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#element_declaration.
    def visitElement_declaration(self, ctx:vhdlParser.Element_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#identifier_list.
    def visitIdentifier_list(self, ctx:vhdlParser.Identifier_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#element_subtype_definition.
    def visitElement_subtype_definition(self, ctx:vhdlParser.Element_subtype_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#record_constraint.
    def visitRecord_constraint(self, ctx:vhdlParser.Record_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#record_element_constraint.
    def visitRecord_element_constraint(self, ctx:vhdlParser.Record_element_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#access_type_definition.
    def visitAccess_type_definition(self, ctx:vhdlParser.Access_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#incomplete_type_declaration.
    def visitIncomplete_type_declaration(self, ctx:vhdlParser.Incomplete_type_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#file_type_definition.
    def visitFile_type_definition(self, ctx:vhdlParser.File_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#protected_type_definition.
    def visitProtected_type_definition(self, ctx:vhdlParser.Protected_type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#protected_type_declaration.
    def visitProtected_type_declaration(self, ctx:vhdlParser.Protected_type_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#protected_type_declarative_item.
    def visitProtected_type_declarative_item(self, ctx:vhdlParser.Protected_type_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#protected_type_body.
    def visitProtected_type_body(self, ctx:vhdlParser.Protected_type_bodyContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#type_declaration.
    def visitType_declaration(self, ctx:vhdlParser.Type_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#full_type_declaration.
    def visitFull_type_declaration(self, ctx:vhdlParser.Full_type_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#type_definition.
    def visitType_definition(self, ctx:vhdlParser.Type_definitionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subtype_declaration.
    def visitSubtype_declaration(self, ctx:vhdlParser.Subtype_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#subtype_indication.
    def visitSubtype_indication(self, ctx:vhdlParser.Subtype_indicationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#resolution_indication.
    def visitResolution_indication(self, ctx:vhdlParser.Resolution_indicationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#element_resolution.
    def visitElement_resolution(self, ctx:vhdlParser.Element_resolutionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#array_element_resolution.
    def visitArray_element_resolution(self, ctx:vhdlParser.Array_element_resolutionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#record_resolution.
    def visitRecord_resolution(self, ctx:vhdlParser.Record_resolutionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#record_element_resolution.
    def visitRecord_element_resolution(self, ctx:vhdlParser.Record_element_resolutionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#type_mark.
    def visitType_mark(self, ctx:vhdlParser.Type_markContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#constraint.
    def visitConstraint(self, ctx:vhdlParser.ConstraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#element_constraint.
    def visitElement_constraint(self, ctx:vhdlParser.Element_constraintContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#object_declaration.
    def visitObject_declaration(self, ctx:vhdlParser.Object_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#constant_declaration.
    def visitConstant_declaration(self, ctx:vhdlParser.Constant_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#signal_declaration.
    def visitSignal_declaration(self, ctx:vhdlParser.Signal_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#signal_kind.
    def visitSignal_kind(self, ctx:vhdlParser.Signal_kindContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#variable_declaration.
    def visitVariable_declaration(self, ctx:vhdlParser.Variable_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#file_declaration.
    def visitFile_declaration(self, ctx:vhdlParser.File_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#file_open_information.
    def visitFile_open_information(self, ctx:vhdlParser.File_open_informationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#file_logical_name.
    def visitFile_logical_name(self, ctx:vhdlParser.File_logical_nameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_declaration.
    def visitInterface_declaration(self, ctx:vhdlParser.Interface_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_object_declaration.
    def visitInterface_object_declaration(self, ctx:vhdlParser.Interface_object_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_constant_declaration.
    def visitInterface_constant_declaration(self, ctx:vhdlParser.Interface_constant_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_signal_declaration.
    def visitInterface_signal_declaration(self, ctx:vhdlParser.Interface_signal_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_variable_declaration.
    def visitInterface_variable_declaration(self, ctx:vhdlParser.Interface_variable_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_file_declaration.
    def visitInterface_file_declaration(self, ctx:vhdlParser.Interface_file_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#signal_mode.
    def visitSignal_mode(self, ctx:vhdlParser.Signal_modeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_type_declaration.
    def visitInterface_type_declaration(self, ctx:vhdlParser.Interface_type_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_incomplete_type_declaration.
    def visitInterface_incomplete_type_declaration(self, ctx:vhdlParser.Interface_incomplete_type_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_subprogram_declaration.
    def visitInterface_subprogram_declaration(self, ctx:vhdlParser.Interface_subprogram_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_subprogram_specification.
    def visitInterface_subprogram_specification(self, ctx:vhdlParser.Interface_subprogram_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_procedure_specification.
    def visitInterface_procedure_specification(self, ctx:vhdlParser.Interface_procedure_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_function_specification.
    def visitInterface_function_specification(self, ctx:vhdlParser.Interface_function_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_subprogram_default.
    def visitInterface_subprogram_default(self, ctx:vhdlParser.Interface_subprogram_defaultContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_package_declaration.
    def visitInterface_package_declaration(self, ctx:vhdlParser.Interface_package_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_package_generic_map_aspect.
    def visitInterface_package_generic_map_aspect(self, ctx:vhdlParser.Interface_package_generic_map_aspectContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_list.
    def visitInterface_list(self, ctx:vhdlParser.Interface_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#interface_element.
    def visitInterface_element(self, ctx:vhdlParser.Interface_elementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generic_clause.
    def visitGeneric_clause(self, ctx:vhdlParser.Generic_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generic_list.
    def visitGeneric_list(self, ctx:vhdlParser.Generic_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#port_clause.
    def visitPort_clause(self, ctx:vhdlParser.Port_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#port_list.
    def visitPort_list(self, ctx:vhdlParser.Port_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#association_list.
    def visitAssociation_list(self, ctx:vhdlParser.Association_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#association_element.
    def visitAssociation_element(self, ctx:vhdlParser.Association_elementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#formal_part.
    def visitFormal_part(self, ctx:vhdlParser.Formal_partContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#actual_part.
    def visitActual_part(self, ctx:vhdlParser.Actual_partContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#actual_designator.
    def visitActual_designator(self, ctx:vhdlParser.Actual_designatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generic_map_aspect.
    def visitGeneric_map_aspect(self, ctx:vhdlParser.Generic_map_aspectContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#port_map_aspect.
    def visitPort_map_aspect(self, ctx:vhdlParser.Port_map_aspectContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#alias_declaration.
    def visitAlias_declaration(self, ctx:vhdlParser.Alias_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#alias_designator.
    def visitAlias_designator(self, ctx:vhdlParser.Alias_designatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#attribute_declaration.
    def visitAttribute_declaration(self, ctx:vhdlParser.Attribute_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#component_declaration.
    def visitComponent_declaration(self, ctx:vhdlParser.Component_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#group_template_declaration.
    def visitGroup_template_declaration(self, ctx:vhdlParser.Group_template_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_class_entry_list.
    def visitEntity_class_entry_list(self, ctx:vhdlParser.Entity_class_entry_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_class_entry.
    def visitEntity_class_entry(self, ctx:vhdlParser.Entity_class_entryContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#group_declaration.
    def visitGroup_declaration(self, ctx:vhdlParser.Group_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#group_constituent_list.
    def visitGroup_constituent_list(self, ctx:vhdlParser.Group_constituent_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#group_constituent.
    def visitGroup_constituent(self, ctx:vhdlParser.Group_constituentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#attribute_specification.
    def visitAttribute_specification(self, ctx:vhdlParser.Attribute_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_specification.
    def visitEntity_specification(self, ctx:vhdlParser.Entity_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_class.
    def visitEntity_class(self, ctx:vhdlParser.Entity_classContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_name_list.
    def visitEntity_name_list(self, ctx:vhdlParser.Entity_name_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_designator.
    def visitEntity_designator(self, ctx:vhdlParser.Entity_designatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_tag.
    def visitEntity_tag(self, ctx:vhdlParser.Entity_tagContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#configuration_specification.
    def visitConfiguration_specification(self, ctx:vhdlParser.Configuration_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_configuration_specification.
    def visitSimple_configuration_specification(self, ctx:vhdlParser.Simple_configuration_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#compound_configuration_specification.
    def visitCompound_configuration_specification(self, ctx:vhdlParser.Compound_configuration_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#component_specification.
    def visitComponent_specification(self, ctx:vhdlParser.Component_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#instantiation_list.
    def visitInstantiation_list(self, ctx:vhdlParser.Instantiation_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#binding_indication.
    def visitBinding_indication(self, ctx:vhdlParser.Binding_indicationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#entity_aspect.
    def visitEntity_aspect(self, ctx:vhdlParser.Entity_aspectContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#verification_unit_binding_indication.
    def visitVerification_unit_binding_indication(self, ctx:vhdlParser.Verification_unit_binding_indicationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#verification_unit_list.
    def visitVerification_unit_list(self, ctx:vhdlParser.Verification_unit_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#disconnection_specification.
    def visitDisconnection_specification(self, ctx:vhdlParser.Disconnection_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#guarded_signal_specification.
    def visitGuarded_signal_specification(self, ctx:vhdlParser.Guarded_signal_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#signal_list.
    def visitSignal_list(self, ctx:vhdlParser.Signal_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#attribute_designator.
    def visitAttribute_designator(self, ctx:vhdlParser.Attribute_designatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#external_name.
    def visitExternal_name(self, ctx:vhdlParser.External_nameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#external_pathname.
    def visitExternal_pathname(self, ctx:vhdlParser.External_pathnameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#package_pathname.
    def visitPackage_pathname(self, ctx:vhdlParser.Package_pathnameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#absolute_pathname.
    def visitAbsolute_pathname(self, ctx:vhdlParser.Absolute_pathnameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#relative_pathname.
    def visitRelative_pathname(self, ctx:vhdlParser.Relative_pathnameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#partial_pathname.
    def visitPartial_pathname(self, ctx:vhdlParser.Partial_pathnameContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#pathname_element.
    def visitPathname_element(self, ctx:vhdlParser.Pathname_elementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#expression.
    def visitExpression(self, ctx:vhdlParser.ExpressionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_expression.
    def visitSimple_expression(self, ctx:vhdlParser.Simple_expressionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#primary.
    def visitPrimary(self, ctx:vhdlParser.PrimaryContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#logical_operator.
    def visitLogical_operator(self, ctx:vhdlParser.Logical_operatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#relational_operator.
    def visitRelational_operator(self, ctx:vhdlParser.Relational_operatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#shift_operator.
    def visitShift_operator(self, ctx:vhdlParser.Shift_operatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#adding_operator.
    def visitAdding_operator(self, ctx:vhdlParser.Adding_operatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#sign.
    def visitSign(self, ctx:vhdlParser.SignContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#multiplying_operator.
    def visitMultiplying_operator(self, ctx:vhdlParser.Multiplying_operatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#miscellaneous_operator.
    def visitMiscellaneous_operator(self, ctx:vhdlParser.Miscellaneous_operatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#numeric_literal.
    def visitNumeric_literal(self, ctx:vhdlParser.Numeric_literalContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#physical_literal.
    def visitPhysical_literal(self, ctx:vhdlParser.Physical_literalContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#aggregate.
    def visitAggregate(self, ctx:vhdlParser.AggregateContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#element_association.
    def visitElement_association(self, ctx:vhdlParser.Element_associationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#choices.
    def visitChoices(self, ctx:vhdlParser.ChoicesContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#choice.
    def visitChoice(self, ctx:vhdlParser.ChoiceContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#qualified_expression.
    def visitQualified_expression(self, ctx:vhdlParser.Qualified_expressionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#allocator.
    def visitAllocator(self, ctx:vhdlParser.AllocatorContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#sequence_of_statements.
    def visitSequence_of_statements(self, ctx:vhdlParser.Sequence_of_statementsContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#sequential_statement.
    def visitSequential_statement(self, ctx:vhdlParser.Sequential_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#wait_statement.
    def visitWait_statement(self, ctx:vhdlParser.Wait_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#sensitivity_clause.
    def visitSensitivity_clause(self, ctx:vhdlParser.Sensitivity_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#sensitivity_list.
    def visitSensitivity_list(self, ctx:vhdlParser.Sensitivity_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#condition_clause.
    def visitCondition_clause(self, ctx:vhdlParser.Condition_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#condition.
    def visitCondition(self, ctx:vhdlParser.ConditionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#timeout_clause.
    def visitTimeout_clause(self, ctx:vhdlParser.Timeout_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#assertion_statement.
    def visitAssertion_statement(self, ctx:vhdlParser.Assertion_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#assertion.
    def visitAssertion(self, ctx:vhdlParser.AssertionContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#report_statement.
    def visitReport_statement(self, ctx:vhdlParser.Report_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#signal_assignment_statement.
    def visitSignal_assignment_statement(self, ctx:vhdlParser.Signal_assignment_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_signal_assignment.
    def visitSimple_signal_assignment(self, ctx:vhdlParser.Simple_signal_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_waveform_assignment.
    def visitSimple_waveform_assignment(self, ctx:vhdlParser.Simple_waveform_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_force_assignment.
    def visitSimple_force_assignment(self, ctx:vhdlParser.Simple_force_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_release_assignment.
    def visitSimple_release_assignment(self, ctx:vhdlParser.Simple_release_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#force_mode.
    def visitForce_mode(self, ctx:vhdlParser.Force_modeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#delay_mechanism.
    def visitDelay_mechanism(self, ctx:vhdlParser.Delay_mechanismContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#target.
    def visitTarget(self, ctx:vhdlParser.TargetContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#waveform.
    def visitWaveform(self, ctx:vhdlParser.WaveformContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#waveform_element.
    def visitWaveform_element(self, ctx:vhdlParser.Waveform_elementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#conditional_signal_assignment.
    def visitConditional_signal_assignment(self, ctx:vhdlParser.Conditional_signal_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#conditional_waveform_assignment.
    def visitConditional_waveform_assignment(self, ctx:vhdlParser.Conditional_waveform_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#conditional_waveforms.
    def visitConditional_waveforms(self, ctx:vhdlParser.Conditional_waveformsContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#conditional_force_assignment.
    def visitConditional_force_assignment(self, ctx:vhdlParser.Conditional_force_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#conditional_expressions.
    def visitConditional_expressions(self, ctx:vhdlParser.Conditional_expressionsContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_signal_assignment.
    def visitSelected_signal_assignment(self, ctx:vhdlParser.Selected_signal_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_waveform_assignment.
    def visitSelected_waveform_assignment(self, ctx:vhdlParser.Selected_waveform_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_waveforms.
    def visitSelected_waveforms(self, ctx:vhdlParser.Selected_waveformsContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_force_assignment.
    def visitSelected_force_assignment(self, ctx:vhdlParser.Selected_force_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_expressions.
    def visitSelected_expressions(self, ctx:vhdlParser.Selected_expressionsContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#variable_assignment_statement.
    def visitVariable_assignment_statement(self, ctx:vhdlParser.Variable_assignment_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#simple_variable_assignment.
    def visitSimple_variable_assignment(self, ctx:vhdlParser.Simple_variable_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#conditional_variable_assignment.
    def visitConditional_variable_assignment(self, ctx:vhdlParser.Conditional_variable_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#selected_variable_assignment.
    def visitSelected_variable_assignment(self, ctx:vhdlParser.Selected_variable_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#procedure_call_statement.
    def visitProcedure_call_statement(self, ctx:vhdlParser.Procedure_call_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#procedure_call.
    def visitProcedure_call(self, ctx:vhdlParser.Procedure_callContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#if_statement.
    def visitIf_statement(self, ctx:vhdlParser.If_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#case_statement.
    def visitCase_statement(self, ctx:vhdlParser.Case_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#case_statement_alternative.
    def visitCase_statement_alternative(self, ctx:vhdlParser.Case_statement_alternativeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#loop_statement.
    def visitLoop_statement(self, ctx:vhdlParser.Loop_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#iteration_scheme.
    def visitIteration_scheme(self, ctx:vhdlParser.Iteration_schemeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#parameter_specification.
    def visitParameter_specification(self, ctx:vhdlParser.Parameter_specificationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#next_statement.
    def visitNext_statement(self, ctx:vhdlParser.Next_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#exit_statement.
    def visitExit_statement(self, ctx:vhdlParser.Exit_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#return_statement.
    def visitReturn_statement(self, ctx:vhdlParser.Return_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#null_statement.
    def visitNull_statement(self, ctx:vhdlParser.Null_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_statement_with_optional_label.
    def visitConcurrent_statement_with_optional_label(self, ctx:vhdlParser.Concurrent_statement_with_optional_labelContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_statement.
    def visitConcurrent_statement(self, ctx:vhdlParser.Concurrent_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#block_statement.
    def visitBlock_statement(self, ctx:vhdlParser.Block_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#block_header.
    def visitBlock_header(self, ctx:vhdlParser.Block_headerContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#process_statement.
    def visitProcess_statement(self, ctx:vhdlParser.Process_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#process_sensitivity_list.
    def visitProcess_sensitivity_list(self, ctx:vhdlParser.Process_sensitivity_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#process_or_package_declarative_item.
    def visitProcess_or_package_declarative_item(self, ctx:vhdlParser.Process_or_package_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#process_declarative_item.
    def visitProcess_declarative_item(self, ctx:vhdlParser.Process_declarative_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_procedure_call_statement.
    def visitConcurrent_procedure_call_statement(self, ctx:vhdlParser.Concurrent_procedure_call_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_assertion_statement.
    def visitConcurrent_assertion_statement(self, ctx:vhdlParser.Concurrent_assertion_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_signal_assignment_statement.
    def visitConcurrent_signal_assignment_statement(self, ctx:vhdlParser.Concurrent_signal_assignment_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_signal_assignment_any.
    def visitConcurrent_signal_assignment_any(self, ctx:vhdlParser.Concurrent_signal_assignment_anyContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#concurrent_selected_signal_assignment.
    def visitConcurrent_selected_signal_assignment(self, ctx:vhdlParser.Concurrent_selected_signal_assignmentContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#component_instantiation_statement.
    def visitComponent_instantiation_statement(self, ctx:vhdlParser.Component_instantiation_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#instantiated_unit.
    def visitInstantiated_unit(self, ctx:vhdlParser.Instantiated_unitContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generate_statement.
    def visitGenerate_statement(self, ctx:vhdlParser.Generate_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#for_generate_statement.
    def visitFor_generate_statement(self, ctx:vhdlParser.For_generate_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#if_generate_statement.
    def visitIf_generate_statement(self, ctx:vhdlParser.If_generate_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#case_generate_statement.
    def visitCase_generate_statement(self, ctx:vhdlParser.Case_generate_statementContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#case_generate_alternative.
    def visitCase_generate_alternative(self, ctx:vhdlParser.Case_generate_alternativeContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generate_statement_body_with_begin_end.
    def visitGenerate_statement_body_with_begin_end(self, ctx:vhdlParser.Generate_statement_body_with_begin_endContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#generate_statement_body.
    def visitGenerate_statement_body(self, ctx:vhdlParser.Generate_statement_bodyContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#label.
    def visitLabel(self, ctx:vhdlParser.LabelContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#use_clause.
    def visitUse_clause(self, ctx:vhdlParser.Use_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#design_file.
    def visitDesign_file(self, ctx:vhdlParser.Design_fileContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#design_unit.
    def visitDesign_unit(self, ctx:vhdlParser.Design_unitContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#library_unit.
    def visitLibrary_unit(self, ctx:vhdlParser.Library_unitContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#primary_unit.
    def visitPrimary_unit(self, ctx:vhdlParser.Primary_unitContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#secondary_unit.
    def visitSecondary_unit(self, ctx:vhdlParser.Secondary_unitContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#library_clause.
    def visitLibrary_clause(self, ctx:vhdlParser.Library_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#logical_name_list.
    def visitLogical_name_list(self, ctx:vhdlParser.Logical_name_listContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#context_declaration.
    def visitContext_declaration(self, ctx:vhdlParser.Context_declarationContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#context_clause.
    def visitContext_clause(self, ctx:vhdlParser.Context_clauseContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#context_item.
    def visitContext_item(self, ctx:vhdlParser.Context_itemContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#context_reference.
    def visitContext_reference(self, ctx:vhdlParser.Context_referenceContext):
        return self.visitChildren(ctx)


    # Visit a parse tree produced by vhdlParser#identifier.
    def visitIdentifier(self, ctx:vhdlParser.IdentifierContext):
        return self.visitChildren(ctx)



del vhdlParser


from functools import lru_cache
from typing import Tuple, Dict, List, Optional
from pathlib import Path

import dovado_rtl.vivado_interaction as vivado
import dovado_rtl.report_parsing as report
from dovado_rtl.frame_handling import (
    HdlBoxFrameHandler,
    TclFrameHandler,
)
from dovado_rtl.config import Configuration
from dovado_rtl.simple_types import IsIncremental, DesignValue, Metric
from dovado_rtl.enums import StopStep
from dovado_rtl.cli_utility import ask_utilization_metrics
from dovado_rtl.report_parsing import get_available_indices
from dovado_rtl.abstract_classes import (
    AbstractDesignPointEvaluator,
    AbstractEstimator,
    AbstractSourceParser,
)


class DesignPointEvaluator(AbstractDesignPointEvaluator):
    def __init__(
        self,
        config: Configuration,
        parsed_source: AbstractSourceParser,
        hdl_handler: HdlBoxFrameHandler,
        tcl_handler: TclFrameHandler,
        target_clock: float,
        is_incremental: IsIncremental,
        stop_step: StopStep,
        free_parameters: List[str],
        int_metrics: Optional[List[int]],
    ):
        self.__hdl_handler: HdlBoxFrameHandler = hdl_handler
        self.__stop_step: StopStep = stop_step
        self.__parsed_file = parsed_source
        self.__target_clock: float = target_clock
        self.__is_incremental: IsIncremental = is_incremental
        self.__is_first_evaluation: bool = True
        self.__free_parameters: List[str] = free_parameters
        self.__config: Configuration = config
        self.__tcl_handler: TclFrameHandler = tcl_handler
        self.__metrics: Optional[List[Metric]] = None
        self.__int_metrics: Optional[List[int]] = int_metrics
        self.__estimator: Optional[AbstractEstimator] = None

    @lru_cache()
    def evaluate(self, design_point: Tuple[int, ...]) -> Optional[DesignValue]:

        self.__parsed_file.write_parameter_values(
            self.__hdl_handler,
            dict(zip(self.__free_parameters, design_point)),
        )

        vivado_out, success = vivado.source(
            str(self.__config.get_config("WORK_DIR"))
            + str(self.__config.get_config(self.__stop_step.name))
        )

        print(vivado_out)
        if self.__is_first_evaluation:
            if not success:
                return None
            if not self.__metrics:
                self.__metrics = ask_utilization_metrics(
                    get_available_indices(
                        str(self.__config.get_config("WORK_DIR"))
                        + str(
                            self.__config.get_config(
                                self.__stop_step.name + "_UTILISATION"
                            )
                        )
                    ),
                    self.__int_metrics,
                )
            self.__is_first_evaluation = False

        if not success:
            met: Dict[Metric, float] = {}
            for i in self.__metrics:
                if i.is_frequency:
                    met[i] = float(0)
                else:
                    met[i] = float(100)
            design_value = DesignValue(met)
        else:
            design_value = DesignValue(
                value={
                    i: report.get_utilisation(
                        str(self.__config.get_config("WORK_DIR"))
                        + (
                            str(
                                self.__config.get_config(
                                    self.__stop_step.name + "_UTILISATION"
                                )
                            )
                        ),
                        i.utilisation[0],
                        i.utilisation[1],
                    )
                    for i in self.__metrics
                    if not i.is_frequency and i.utilisation
                },
            )
            for i in self.__metrics:
                if i.is_frequency:
                    design_value.value[i] = -self.get_max_frequency(
                        report.get_wns(
                            str(self.__config.get_config("WORK_DIR"))
                            + (
                                str(
                                    self.__config.get_config(
                                        self.__stop_step.name + "_TIMING"
                                    )
                                )
                            )
                        )
                    )
                    break

        return design_value

    def get_max_frequency(self, wns: float) -> float:

        return 1000 / (1 / (1 / 1000 * self.__target_clock) - wns)

    def set_metrics(self, metrics: List[Metric]):
        if self.__metrics:
            raise Exception(
                "Metrics already set with value: "
                + str(self.__metrics)
                + " resetting forbidden. Trying to reset with value "
                + str(metrics)
            )
        self.__metrics = metrics

    def __write_csv(
        self, estimated_value: float, real_value: float, metric: str
    ):
        Path(
            str(self.__config.get_config("WORK_DIRECTORY"))
            + str(self.__config.get_config("EST_TEST_CSV"))
        ).open(mode="a+").writelines(
            [str(estimated_value) + "," + str(real_value) + "," + metric]
        )

    def set_estimator(self, estimator: AbstractEstimator) -> None:
        self.__estimator = estimator

    def get_metrics(self):
        return self.__metrics



# Generated from vhdlParser.g4 by ANTLR 4.8
from antlr4 import *
if __name__ is not None and "." in __name__:
    from .vhdlParser import vhdlParser
else:
    from vhdlParser import vhdlParser

# This class defines a complete listener for a parse tree produced by vhdlParser.
class vhdlParserListener(ParseTreeListener):

    # Enter a parse tree produced by vhdlParser#any_keyword.
    def enterAny_keyword(self, ctx:vhdlParser.Any_keywordContext):
        pass

    # Exit a parse tree produced by vhdlParser#any_keyword.
    def exitAny_keyword(self, ctx:vhdlParser.Any_keywordContext):
        pass


    # Enter a parse tree produced by vhdlParser#name_literal.
    def enterName_literal(self, ctx:vhdlParser.Name_literalContext):
        pass

    # Exit a parse tree produced by vhdlParser#name_literal.
    def exitName_literal(self, ctx:vhdlParser.Name_literalContext):
        pass


    # Enter a parse tree produced by vhdlParser#name.
    def enterName(self, ctx:vhdlParser.NameContext):
        pass

    # Exit a parse tree produced by vhdlParser#name.
    def exitName(self, ctx:vhdlParser.NameContext):
        pass


    # Enter a parse tree produced by vhdlParser#name_slice_part.
    def enterName_slice_part(self, ctx:vhdlParser.Name_slice_partContext):
        pass

    # Exit a parse tree produced by vhdlParser#name_slice_part.
    def exitName_slice_part(self, ctx:vhdlParser.Name_slice_partContext):
        pass


    # Enter a parse tree produced by vhdlParser#name_attribute_part.
    def enterName_attribute_part(self, ctx:vhdlParser.Name_attribute_partContext):
        pass

    # Exit a parse tree produced by vhdlParser#name_attribute_part.
    def exitName_attribute_part(self, ctx:vhdlParser.Name_attribute_partContext):
        pass


    # Enter a parse tree produced by vhdlParser#attribute_name.
    def enterAttribute_name(self, ctx:vhdlParser.Attribute_nameContext):
        pass

    # Exit a parse tree produced by vhdlParser#attribute_name.
    def exitAttribute_name(self, ctx:vhdlParser.Attribute_nameContext):
        pass


    # Enter a parse tree produced by vhdlParser#suffix.
    def enterSuffix(self, ctx:vhdlParser.SuffixContext):
        pass

    # Exit a parse tree produced by vhdlParser#suffix.
    def exitSuffix(self, ctx:vhdlParser.SuffixContext):
        pass


    # Enter a parse tree produced by vhdlParser#explicit_range.
    def enterExplicit_range(self, ctx:vhdlParser.Explicit_rangeContext):
        pass

    # Exit a parse tree produced by vhdlParser#explicit_range.
    def exitExplicit_range(self, ctx:vhdlParser.Explicit_rangeContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_name.
    def enterSelected_name(self, ctx:vhdlParser.Selected_nameContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_name.
    def exitSelected_name(self, ctx:vhdlParser.Selected_nameContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_declaration.
    def enterEntity_declaration(self, ctx:vhdlParser.Entity_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_declaration.
    def exitEntity_declaration(self, ctx:vhdlParser.Entity_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_declarative_item.
    def enterEntity_declarative_item(self, ctx:vhdlParser.Entity_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_declarative_item.
    def exitEntity_declarative_item(self, ctx:vhdlParser.Entity_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_statement.
    def enterEntity_statement(self, ctx:vhdlParser.Entity_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_statement.
    def exitEntity_statement(self, ctx:vhdlParser.Entity_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#architecture_body.
    def enterArchitecture_body(self, ctx:vhdlParser.Architecture_bodyContext):
        pass

    # Exit a parse tree produced by vhdlParser#architecture_body.
    def exitArchitecture_body(self, ctx:vhdlParser.Architecture_bodyContext):
        pass


    # Enter a parse tree produced by vhdlParser#block_declarative_item.
    def enterBlock_declarative_item(self, ctx:vhdlParser.Block_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#block_declarative_item.
    def exitBlock_declarative_item(self, ctx:vhdlParser.Block_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#configuration_declaration.
    def enterConfiguration_declaration(self, ctx:vhdlParser.Configuration_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#configuration_declaration.
    def exitConfiguration_declaration(self, ctx:vhdlParser.Configuration_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#configuration_declarative_item.
    def enterConfiguration_declarative_item(self, ctx:vhdlParser.Configuration_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#configuration_declarative_item.
    def exitConfiguration_declarative_item(self, ctx:vhdlParser.Configuration_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#block_configuration.
    def enterBlock_configuration(self, ctx:vhdlParser.Block_configurationContext):
        pass

    # Exit a parse tree produced by vhdlParser#block_configuration.
    def exitBlock_configuration(self, ctx:vhdlParser.Block_configurationContext):
        pass


    # Enter a parse tree produced by vhdlParser#block_specification.
    def enterBlock_specification(self, ctx:vhdlParser.Block_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#block_specification.
    def exitBlock_specification(self, ctx:vhdlParser.Block_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#generate_specification.
    def enterGenerate_specification(self, ctx:vhdlParser.Generate_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#generate_specification.
    def exitGenerate_specification(self, ctx:vhdlParser.Generate_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#configuration_item.
    def enterConfiguration_item(self, ctx:vhdlParser.Configuration_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#configuration_item.
    def exitConfiguration_item(self, ctx:vhdlParser.Configuration_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#component_configuration.
    def enterComponent_configuration(self, ctx:vhdlParser.Component_configurationContext):
        pass

    # Exit a parse tree produced by vhdlParser#component_configuration.
    def exitComponent_configuration(self, ctx:vhdlParser.Component_configurationContext):
        pass


    # Enter a parse tree produced by vhdlParser#subprogram_declaration.
    def enterSubprogram_declaration(self, ctx:vhdlParser.Subprogram_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#subprogram_declaration.
    def exitSubprogram_declaration(self, ctx:vhdlParser.Subprogram_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#subprogram_specification.
    def enterSubprogram_specification(self, ctx:vhdlParser.Subprogram_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#subprogram_specification.
    def exitSubprogram_specification(self, ctx:vhdlParser.Subprogram_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#procedure_specification.
    def enterProcedure_specification(self, ctx:vhdlParser.Procedure_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#procedure_specification.
    def exitProcedure_specification(self, ctx:vhdlParser.Procedure_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#function_specification.
    def enterFunction_specification(self, ctx:vhdlParser.Function_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#function_specification.
    def exitFunction_specification(self, ctx:vhdlParser.Function_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#subprogram_header.
    def enterSubprogram_header(self, ctx:vhdlParser.Subprogram_headerContext):
        pass

    # Exit a parse tree produced by vhdlParser#subprogram_header.
    def exitSubprogram_header(self, ctx:vhdlParser.Subprogram_headerContext):
        pass


    # Enter a parse tree produced by vhdlParser#designator.
    def enterDesignator(self, ctx:vhdlParser.DesignatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#designator.
    def exitDesignator(self, ctx:vhdlParser.DesignatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#operator_symbol.
    def enterOperator_symbol(self, ctx:vhdlParser.Operator_symbolContext):
        pass

    # Exit a parse tree produced by vhdlParser#operator_symbol.
    def exitOperator_symbol(self, ctx:vhdlParser.Operator_symbolContext):
        pass


    # Enter a parse tree produced by vhdlParser#formal_parameter_list.
    def enterFormal_parameter_list(self, ctx:vhdlParser.Formal_parameter_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#formal_parameter_list.
    def exitFormal_parameter_list(self, ctx:vhdlParser.Formal_parameter_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#subprogram_body.
    def enterSubprogram_body(self, ctx:vhdlParser.Subprogram_bodyContext):
        pass

    # Exit a parse tree produced by vhdlParser#subprogram_body.
    def exitSubprogram_body(self, ctx:vhdlParser.Subprogram_bodyContext):
        pass


    # Enter a parse tree produced by vhdlParser#subprogram_kind.
    def enterSubprogram_kind(self, ctx:vhdlParser.Subprogram_kindContext):
        pass

    # Exit a parse tree produced by vhdlParser#subprogram_kind.
    def exitSubprogram_kind(self, ctx:vhdlParser.Subprogram_kindContext):
        pass


    # Enter a parse tree produced by vhdlParser#subprogram_instantiation_declaration.
    def enterSubprogram_instantiation_declaration(self, ctx:vhdlParser.Subprogram_instantiation_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#subprogram_instantiation_declaration.
    def exitSubprogram_instantiation_declaration(self, ctx:vhdlParser.Subprogram_instantiation_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#signature.
    def enterSignature(self, ctx:vhdlParser.SignatureContext):
        pass

    # Exit a parse tree produced by vhdlParser#signature.
    def exitSignature(self, ctx:vhdlParser.SignatureContext):
        pass


    # Enter a parse tree produced by vhdlParser#package_declaration.
    def enterPackage_declaration(self, ctx:vhdlParser.Package_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#package_declaration.
    def exitPackage_declaration(self, ctx:vhdlParser.Package_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#package_declarative_item.
    def enterPackage_declarative_item(self, ctx:vhdlParser.Package_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#package_declarative_item.
    def exitPackage_declarative_item(self, ctx:vhdlParser.Package_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#package_body.
    def enterPackage_body(self, ctx:vhdlParser.Package_bodyContext):
        pass

    # Exit a parse tree produced by vhdlParser#package_body.
    def exitPackage_body(self, ctx:vhdlParser.Package_bodyContext):
        pass


    # Enter a parse tree produced by vhdlParser#package_instantiation_declaration.
    def enterPackage_instantiation_declaration(self, ctx:vhdlParser.Package_instantiation_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#package_instantiation_declaration.
    def exitPackage_instantiation_declaration(self, ctx:vhdlParser.Package_instantiation_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#scalar_type_definition.
    def enterScalar_type_definition(self, ctx:vhdlParser.Scalar_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#scalar_type_definition.
    def exitScalar_type_definition(self, ctx:vhdlParser.Scalar_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#range_constraint.
    def enterRange_constraint(self, ctx:vhdlParser.Range_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#range_constraint.
    def exitRange_constraint(self, ctx:vhdlParser.Range_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#range_.
    def enterRange_(self, ctx:vhdlParser.Range_Context):
        pass

    # Exit a parse tree produced by vhdlParser#range_.
    def exitRange_(self, ctx:vhdlParser.Range_Context):
        pass


    # Enter a parse tree produced by vhdlParser#direction.
    def enterDirection(self, ctx:vhdlParser.DirectionContext):
        pass

    # Exit a parse tree produced by vhdlParser#direction.
    def exitDirection(self, ctx:vhdlParser.DirectionContext):
        pass


    # Enter a parse tree produced by vhdlParser#enumeration_type_definition.
    def enterEnumeration_type_definition(self, ctx:vhdlParser.Enumeration_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#enumeration_type_definition.
    def exitEnumeration_type_definition(self, ctx:vhdlParser.Enumeration_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#enumeration_literal.
    def enterEnumeration_literal(self, ctx:vhdlParser.Enumeration_literalContext):
        pass

    # Exit a parse tree produced by vhdlParser#enumeration_literal.
    def exitEnumeration_literal(self, ctx:vhdlParser.Enumeration_literalContext):
        pass


    # Enter a parse tree produced by vhdlParser#integer_type_definition.
    def enterInteger_type_definition(self, ctx:vhdlParser.Integer_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#integer_type_definition.
    def exitInteger_type_definition(self, ctx:vhdlParser.Integer_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#physical_type_definition.
    def enterPhysical_type_definition(self, ctx:vhdlParser.Physical_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#physical_type_definition.
    def exitPhysical_type_definition(self, ctx:vhdlParser.Physical_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#primary_unit_declaration.
    def enterPrimary_unit_declaration(self, ctx:vhdlParser.Primary_unit_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#primary_unit_declaration.
    def exitPrimary_unit_declaration(self, ctx:vhdlParser.Primary_unit_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#secondary_unit_declaration.
    def enterSecondary_unit_declaration(self, ctx:vhdlParser.Secondary_unit_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#secondary_unit_declaration.
    def exitSecondary_unit_declaration(self, ctx:vhdlParser.Secondary_unit_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#floating_type_definition.
    def enterFloating_type_definition(self, ctx:vhdlParser.Floating_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#floating_type_definition.
    def exitFloating_type_definition(self, ctx:vhdlParser.Floating_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#composite_type_definition.
    def enterComposite_type_definition(self, ctx:vhdlParser.Composite_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#composite_type_definition.
    def exitComposite_type_definition(self, ctx:vhdlParser.Composite_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#array_type_definition.
    def enterArray_type_definition(self, ctx:vhdlParser.Array_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#array_type_definition.
    def exitArray_type_definition(self, ctx:vhdlParser.Array_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#unbounded_array_definition.
    def enterUnbounded_array_definition(self, ctx:vhdlParser.Unbounded_array_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#unbounded_array_definition.
    def exitUnbounded_array_definition(self, ctx:vhdlParser.Unbounded_array_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#constrained_array_definition.
    def enterConstrained_array_definition(self, ctx:vhdlParser.Constrained_array_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#constrained_array_definition.
    def exitConstrained_array_definition(self, ctx:vhdlParser.Constrained_array_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#index_subtype_definition.
    def enterIndex_subtype_definition(self, ctx:vhdlParser.Index_subtype_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#index_subtype_definition.
    def exitIndex_subtype_definition(self, ctx:vhdlParser.Index_subtype_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#array_constraint.
    def enterArray_constraint(self, ctx:vhdlParser.Array_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#array_constraint.
    def exitArray_constraint(self, ctx:vhdlParser.Array_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#array_element_constraint.
    def enterArray_element_constraint(self, ctx:vhdlParser.Array_element_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#array_element_constraint.
    def exitArray_element_constraint(self, ctx:vhdlParser.Array_element_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#index_constraint.
    def enterIndex_constraint(self, ctx:vhdlParser.Index_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#index_constraint.
    def exitIndex_constraint(self, ctx:vhdlParser.Index_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#discrete_range.
    def enterDiscrete_range(self, ctx:vhdlParser.Discrete_rangeContext):
        pass

    # Exit a parse tree produced by vhdlParser#discrete_range.
    def exitDiscrete_range(self, ctx:vhdlParser.Discrete_rangeContext):
        pass


    # Enter a parse tree produced by vhdlParser#record_type_definition.
    def enterRecord_type_definition(self, ctx:vhdlParser.Record_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#record_type_definition.
    def exitRecord_type_definition(self, ctx:vhdlParser.Record_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#element_declaration.
    def enterElement_declaration(self, ctx:vhdlParser.Element_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#element_declaration.
    def exitElement_declaration(self, ctx:vhdlParser.Element_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#identifier_list.
    def enterIdentifier_list(self, ctx:vhdlParser.Identifier_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#identifier_list.
    def exitIdentifier_list(self, ctx:vhdlParser.Identifier_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#element_subtype_definition.
    def enterElement_subtype_definition(self, ctx:vhdlParser.Element_subtype_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#element_subtype_definition.
    def exitElement_subtype_definition(self, ctx:vhdlParser.Element_subtype_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#record_constraint.
    def enterRecord_constraint(self, ctx:vhdlParser.Record_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#record_constraint.
    def exitRecord_constraint(self, ctx:vhdlParser.Record_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#record_element_constraint.
    def enterRecord_element_constraint(self, ctx:vhdlParser.Record_element_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#record_element_constraint.
    def exitRecord_element_constraint(self, ctx:vhdlParser.Record_element_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#access_type_definition.
    def enterAccess_type_definition(self, ctx:vhdlParser.Access_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#access_type_definition.
    def exitAccess_type_definition(self, ctx:vhdlParser.Access_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#incomplete_type_declaration.
    def enterIncomplete_type_declaration(self, ctx:vhdlParser.Incomplete_type_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#incomplete_type_declaration.
    def exitIncomplete_type_declaration(self, ctx:vhdlParser.Incomplete_type_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#file_type_definition.
    def enterFile_type_definition(self, ctx:vhdlParser.File_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#file_type_definition.
    def exitFile_type_definition(self, ctx:vhdlParser.File_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#protected_type_definition.
    def enterProtected_type_definition(self, ctx:vhdlParser.Protected_type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#protected_type_definition.
    def exitProtected_type_definition(self, ctx:vhdlParser.Protected_type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#protected_type_declaration.
    def enterProtected_type_declaration(self, ctx:vhdlParser.Protected_type_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#protected_type_declaration.
    def exitProtected_type_declaration(self, ctx:vhdlParser.Protected_type_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#protected_type_declarative_item.
    def enterProtected_type_declarative_item(self, ctx:vhdlParser.Protected_type_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#protected_type_declarative_item.
    def exitProtected_type_declarative_item(self, ctx:vhdlParser.Protected_type_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#protected_type_body.
    def enterProtected_type_body(self, ctx:vhdlParser.Protected_type_bodyContext):
        pass

    # Exit a parse tree produced by vhdlParser#protected_type_body.
    def exitProtected_type_body(self, ctx:vhdlParser.Protected_type_bodyContext):
        pass


    # Enter a parse tree produced by vhdlParser#type_declaration.
    def enterType_declaration(self, ctx:vhdlParser.Type_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#type_declaration.
    def exitType_declaration(self, ctx:vhdlParser.Type_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#full_type_declaration.
    def enterFull_type_declaration(self, ctx:vhdlParser.Full_type_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#full_type_declaration.
    def exitFull_type_declaration(self, ctx:vhdlParser.Full_type_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#type_definition.
    def enterType_definition(self, ctx:vhdlParser.Type_definitionContext):
        pass

    # Exit a parse tree produced by vhdlParser#type_definition.
    def exitType_definition(self, ctx:vhdlParser.Type_definitionContext):
        pass


    # Enter a parse tree produced by vhdlParser#subtype_declaration.
    def enterSubtype_declaration(self, ctx:vhdlParser.Subtype_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#subtype_declaration.
    def exitSubtype_declaration(self, ctx:vhdlParser.Subtype_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#subtype_indication.
    def enterSubtype_indication(self, ctx:vhdlParser.Subtype_indicationContext):
        pass

    # Exit a parse tree produced by vhdlParser#subtype_indication.
    def exitSubtype_indication(self, ctx:vhdlParser.Subtype_indicationContext):
        pass


    # Enter a parse tree produced by vhdlParser#resolution_indication.
    def enterResolution_indication(self, ctx:vhdlParser.Resolution_indicationContext):
        pass

    # Exit a parse tree produced by vhdlParser#resolution_indication.
    def exitResolution_indication(self, ctx:vhdlParser.Resolution_indicationContext):
        pass


    # Enter a parse tree produced by vhdlParser#element_resolution.
    def enterElement_resolution(self, ctx:vhdlParser.Element_resolutionContext):
        pass

    # Exit a parse tree produced by vhdlParser#element_resolution.
    def exitElement_resolution(self, ctx:vhdlParser.Element_resolutionContext):
        pass


    # Enter a parse tree produced by vhdlParser#array_element_resolution.
    def enterArray_element_resolution(self, ctx:vhdlParser.Array_element_resolutionContext):
        pass

    # Exit a parse tree produced by vhdlParser#array_element_resolution.
    def exitArray_element_resolution(self, ctx:vhdlParser.Array_element_resolutionContext):
        pass


    # Enter a parse tree produced by vhdlParser#record_resolution.
    def enterRecord_resolution(self, ctx:vhdlParser.Record_resolutionContext):
        pass

    # Exit a parse tree produced by vhdlParser#record_resolution.
    def exitRecord_resolution(self, ctx:vhdlParser.Record_resolutionContext):
        pass


    # Enter a parse tree produced by vhdlParser#record_element_resolution.
    def enterRecord_element_resolution(self, ctx:vhdlParser.Record_element_resolutionContext):
        pass

    # Exit a parse tree produced by vhdlParser#record_element_resolution.
    def exitRecord_element_resolution(self, ctx:vhdlParser.Record_element_resolutionContext):
        pass


    # Enter a parse tree produced by vhdlParser#type_mark.
    def enterType_mark(self, ctx:vhdlParser.Type_markContext):
        pass

    # Exit a parse tree produced by vhdlParser#type_mark.
    def exitType_mark(self, ctx:vhdlParser.Type_markContext):
        pass


    # Enter a parse tree produced by vhdlParser#constraint.
    def enterConstraint(self, ctx:vhdlParser.ConstraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#constraint.
    def exitConstraint(self, ctx:vhdlParser.ConstraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#element_constraint.
    def enterElement_constraint(self, ctx:vhdlParser.Element_constraintContext):
        pass

    # Exit a parse tree produced by vhdlParser#element_constraint.
    def exitElement_constraint(self, ctx:vhdlParser.Element_constraintContext):
        pass


    # Enter a parse tree produced by vhdlParser#object_declaration.
    def enterObject_declaration(self, ctx:vhdlParser.Object_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#object_declaration.
    def exitObject_declaration(self, ctx:vhdlParser.Object_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#constant_declaration.
    def enterConstant_declaration(self, ctx:vhdlParser.Constant_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#constant_declaration.
    def exitConstant_declaration(self, ctx:vhdlParser.Constant_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#signal_declaration.
    def enterSignal_declaration(self, ctx:vhdlParser.Signal_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#signal_declaration.
    def exitSignal_declaration(self, ctx:vhdlParser.Signal_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#signal_kind.
    def enterSignal_kind(self, ctx:vhdlParser.Signal_kindContext):
        pass

    # Exit a parse tree produced by vhdlParser#signal_kind.
    def exitSignal_kind(self, ctx:vhdlParser.Signal_kindContext):
        pass


    # Enter a parse tree produced by vhdlParser#variable_declaration.
    def enterVariable_declaration(self, ctx:vhdlParser.Variable_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#variable_declaration.
    def exitVariable_declaration(self, ctx:vhdlParser.Variable_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#file_declaration.
    def enterFile_declaration(self, ctx:vhdlParser.File_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#file_declaration.
    def exitFile_declaration(self, ctx:vhdlParser.File_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#file_open_information.
    def enterFile_open_information(self, ctx:vhdlParser.File_open_informationContext):
        pass

    # Exit a parse tree produced by vhdlParser#file_open_information.
    def exitFile_open_information(self, ctx:vhdlParser.File_open_informationContext):
        pass


    # Enter a parse tree produced by vhdlParser#file_logical_name.
    def enterFile_logical_name(self, ctx:vhdlParser.File_logical_nameContext):
        pass

    # Exit a parse tree produced by vhdlParser#file_logical_name.
    def exitFile_logical_name(self, ctx:vhdlParser.File_logical_nameContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_declaration.
    def enterInterface_declaration(self, ctx:vhdlParser.Interface_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_declaration.
    def exitInterface_declaration(self, ctx:vhdlParser.Interface_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_object_declaration.
    def enterInterface_object_declaration(self, ctx:vhdlParser.Interface_object_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_object_declaration.
    def exitInterface_object_declaration(self, ctx:vhdlParser.Interface_object_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_constant_declaration.
    def enterInterface_constant_declaration(self, ctx:vhdlParser.Interface_constant_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_constant_declaration.
    def exitInterface_constant_declaration(self, ctx:vhdlParser.Interface_constant_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_signal_declaration.
    def enterInterface_signal_declaration(self, ctx:vhdlParser.Interface_signal_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_signal_declaration.
    def exitInterface_signal_declaration(self, ctx:vhdlParser.Interface_signal_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_variable_declaration.
    def enterInterface_variable_declaration(self, ctx:vhdlParser.Interface_variable_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_variable_declaration.
    def exitInterface_variable_declaration(self, ctx:vhdlParser.Interface_variable_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_file_declaration.
    def enterInterface_file_declaration(self, ctx:vhdlParser.Interface_file_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_file_declaration.
    def exitInterface_file_declaration(self, ctx:vhdlParser.Interface_file_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#signal_mode.
    def enterSignal_mode(self, ctx:vhdlParser.Signal_modeContext):
        pass

    # Exit a parse tree produced by vhdlParser#signal_mode.
    def exitSignal_mode(self, ctx:vhdlParser.Signal_modeContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_type_declaration.
    def enterInterface_type_declaration(self, ctx:vhdlParser.Interface_type_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_type_declaration.
    def exitInterface_type_declaration(self, ctx:vhdlParser.Interface_type_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_incomplete_type_declaration.
    def enterInterface_incomplete_type_declaration(self, ctx:vhdlParser.Interface_incomplete_type_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_incomplete_type_declaration.
    def exitInterface_incomplete_type_declaration(self, ctx:vhdlParser.Interface_incomplete_type_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_subprogram_declaration.
    def enterInterface_subprogram_declaration(self, ctx:vhdlParser.Interface_subprogram_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_subprogram_declaration.
    def exitInterface_subprogram_declaration(self, ctx:vhdlParser.Interface_subprogram_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_subprogram_specification.
    def enterInterface_subprogram_specification(self, ctx:vhdlParser.Interface_subprogram_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_subprogram_specification.
    def exitInterface_subprogram_specification(self, ctx:vhdlParser.Interface_subprogram_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_procedure_specification.
    def enterInterface_procedure_specification(self, ctx:vhdlParser.Interface_procedure_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_procedure_specification.
    def exitInterface_procedure_specification(self, ctx:vhdlParser.Interface_procedure_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_function_specification.
    def enterInterface_function_specification(self, ctx:vhdlParser.Interface_function_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_function_specification.
    def exitInterface_function_specification(self, ctx:vhdlParser.Interface_function_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_subprogram_default.
    def enterInterface_subprogram_default(self, ctx:vhdlParser.Interface_subprogram_defaultContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_subprogram_default.
    def exitInterface_subprogram_default(self, ctx:vhdlParser.Interface_subprogram_defaultContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_package_declaration.
    def enterInterface_package_declaration(self, ctx:vhdlParser.Interface_package_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_package_declaration.
    def exitInterface_package_declaration(self, ctx:vhdlParser.Interface_package_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_package_generic_map_aspect.
    def enterInterface_package_generic_map_aspect(self, ctx:vhdlParser.Interface_package_generic_map_aspectContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_package_generic_map_aspect.
    def exitInterface_package_generic_map_aspect(self, ctx:vhdlParser.Interface_package_generic_map_aspectContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_list.
    def enterInterface_list(self, ctx:vhdlParser.Interface_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_list.
    def exitInterface_list(self, ctx:vhdlParser.Interface_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#interface_element.
    def enterInterface_element(self, ctx:vhdlParser.Interface_elementContext):
        pass

    # Exit a parse tree produced by vhdlParser#interface_element.
    def exitInterface_element(self, ctx:vhdlParser.Interface_elementContext):
        pass


    # Enter a parse tree produced by vhdlParser#generic_clause.
    def enterGeneric_clause(self, ctx:vhdlParser.Generic_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#generic_clause.
    def exitGeneric_clause(self, ctx:vhdlParser.Generic_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#generic_list.
    def enterGeneric_list(self, ctx:vhdlParser.Generic_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#generic_list.
    def exitGeneric_list(self, ctx:vhdlParser.Generic_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#port_clause.
    def enterPort_clause(self, ctx:vhdlParser.Port_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#port_clause.
    def exitPort_clause(self, ctx:vhdlParser.Port_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#port_list.
    def enterPort_list(self, ctx:vhdlParser.Port_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#port_list.
    def exitPort_list(self, ctx:vhdlParser.Port_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#association_list.
    def enterAssociation_list(self, ctx:vhdlParser.Association_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#association_list.
    def exitAssociation_list(self, ctx:vhdlParser.Association_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#association_element.
    def enterAssociation_element(self, ctx:vhdlParser.Association_elementContext):
        pass

    # Exit a parse tree produced by vhdlParser#association_element.
    def exitAssociation_element(self, ctx:vhdlParser.Association_elementContext):
        pass


    # Enter a parse tree produced by vhdlParser#formal_part.
    def enterFormal_part(self, ctx:vhdlParser.Formal_partContext):
        pass

    # Exit a parse tree produced by vhdlParser#formal_part.
    def exitFormal_part(self, ctx:vhdlParser.Formal_partContext):
        pass


    # Enter a parse tree produced by vhdlParser#actual_part.
    def enterActual_part(self, ctx:vhdlParser.Actual_partContext):
        pass

    # Exit a parse tree produced by vhdlParser#actual_part.
    def exitActual_part(self, ctx:vhdlParser.Actual_partContext):
        pass


    # Enter a parse tree produced by vhdlParser#actual_designator.
    def enterActual_designator(self, ctx:vhdlParser.Actual_designatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#actual_designator.
    def exitActual_designator(self, ctx:vhdlParser.Actual_designatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#generic_map_aspect.
    def enterGeneric_map_aspect(self, ctx:vhdlParser.Generic_map_aspectContext):
        pass

    # Exit a parse tree produced by vhdlParser#generic_map_aspect.
    def exitGeneric_map_aspect(self, ctx:vhdlParser.Generic_map_aspectContext):
        pass


    # Enter a parse tree produced by vhdlParser#port_map_aspect.
    def enterPort_map_aspect(self, ctx:vhdlParser.Port_map_aspectContext):
        pass

    # Exit a parse tree produced by vhdlParser#port_map_aspect.
    def exitPort_map_aspect(self, ctx:vhdlParser.Port_map_aspectContext):
        pass


    # Enter a parse tree produced by vhdlParser#alias_declaration.
    def enterAlias_declaration(self, ctx:vhdlParser.Alias_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#alias_declaration.
    def exitAlias_declaration(self, ctx:vhdlParser.Alias_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#alias_designator.
    def enterAlias_designator(self, ctx:vhdlParser.Alias_designatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#alias_designator.
    def exitAlias_designator(self, ctx:vhdlParser.Alias_designatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#attribute_declaration.
    def enterAttribute_declaration(self, ctx:vhdlParser.Attribute_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#attribute_declaration.
    def exitAttribute_declaration(self, ctx:vhdlParser.Attribute_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#component_declaration.
    def enterComponent_declaration(self, ctx:vhdlParser.Component_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#component_declaration.
    def exitComponent_declaration(self, ctx:vhdlParser.Component_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#group_template_declaration.
    def enterGroup_template_declaration(self, ctx:vhdlParser.Group_template_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#group_template_declaration.
    def exitGroup_template_declaration(self, ctx:vhdlParser.Group_template_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_class_entry_list.
    def enterEntity_class_entry_list(self, ctx:vhdlParser.Entity_class_entry_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_class_entry_list.
    def exitEntity_class_entry_list(self, ctx:vhdlParser.Entity_class_entry_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_class_entry.
    def enterEntity_class_entry(self, ctx:vhdlParser.Entity_class_entryContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_class_entry.
    def exitEntity_class_entry(self, ctx:vhdlParser.Entity_class_entryContext):
        pass


    # Enter a parse tree produced by vhdlParser#group_declaration.
    def enterGroup_declaration(self, ctx:vhdlParser.Group_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#group_declaration.
    def exitGroup_declaration(self, ctx:vhdlParser.Group_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#group_constituent_list.
    def enterGroup_constituent_list(self, ctx:vhdlParser.Group_constituent_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#group_constituent_list.
    def exitGroup_constituent_list(self, ctx:vhdlParser.Group_constituent_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#group_constituent.
    def enterGroup_constituent(self, ctx:vhdlParser.Group_constituentContext):
        pass

    # Exit a parse tree produced by vhdlParser#group_constituent.
    def exitGroup_constituent(self, ctx:vhdlParser.Group_constituentContext):
        pass


    # Enter a parse tree produced by vhdlParser#attribute_specification.
    def enterAttribute_specification(self, ctx:vhdlParser.Attribute_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#attribute_specification.
    def exitAttribute_specification(self, ctx:vhdlParser.Attribute_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_specification.
    def enterEntity_specification(self, ctx:vhdlParser.Entity_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_specification.
    def exitEntity_specification(self, ctx:vhdlParser.Entity_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_class.
    def enterEntity_class(self, ctx:vhdlParser.Entity_classContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_class.
    def exitEntity_class(self, ctx:vhdlParser.Entity_classContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_name_list.
    def enterEntity_name_list(self, ctx:vhdlParser.Entity_name_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_name_list.
    def exitEntity_name_list(self, ctx:vhdlParser.Entity_name_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_designator.
    def enterEntity_designator(self, ctx:vhdlParser.Entity_designatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_designator.
    def exitEntity_designator(self, ctx:vhdlParser.Entity_designatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_tag.
    def enterEntity_tag(self, ctx:vhdlParser.Entity_tagContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_tag.
    def exitEntity_tag(self, ctx:vhdlParser.Entity_tagContext):
        pass


    # Enter a parse tree produced by vhdlParser#configuration_specification.
    def enterConfiguration_specification(self, ctx:vhdlParser.Configuration_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#configuration_specification.
    def exitConfiguration_specification(self, ctx:vhdlParser.Configuration_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_configuration_specification.
    def enterSimple_configuration_specification(self, ctx:vhdlParser.Simple_configuration_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_configuration_specification.
    def exitSimple_configuration_specification(self, ctx:vhdlParser.Simple_configuration_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#compound_configuration_specification.
    def enterCompound_configuration_specification(self, ctx:vhdlParser.Compound_configuration_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#compound_configuration_specification.
    def exitCompound_configuration_specification(self, ctx:vhdlParser.Compound_configuration_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#component_specification.
    def enterComponent_specification(self, ctx:vhdlParser.Component_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#component_specification.
    def exitComponent_specification(self, ctx:vhdlParser.Component_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#instantiation_list.
    def enterInstantiation_list(self, ctx:vhdlParser.Instantiation_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#instantiation_list.
    def exitInstantiation_list(self, ctx:vhdlParser.Instantiation_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#binding_indication.
    def enterBinding_indication(self, ctx:vhdlParser.Binding_indicationContext):
        pass

    # Exit a parse tree produced by vhdlParser#binding_indication.
    def exitBinding_indication(self, ctx:vhdlParser.Binding_indicationContext):
        pass


    # Enter a parse tree produced by vhdlParser#entity_aspect.
    def enterEntity_aspect(self, ctx:vhdlParser.Entity_aspectContext):
        pass

    # Exit a parse tree produced by vhdlParser#entity_aspect.
    def exitEntity_aspect(self, ctx:vhdlParser.Entity_aspectContext):
        pass


    # Enter a parse tree produced by vhdlParser#verification_unit_binding_indication.
    def enterVerification_unit_binding_indication(self, ctx:vhdlParser.Verification_unit_binding_indicationContext):
        pass

    # Exit a parse tree produced by vhdlParser#verification_unit_binding_indication.
    def exitVerification_unit_binding_indication(self, ctx:vhdlParser.Verification_unit_binding_indicationContext):
        pass


    # Enter a parse tree produced by vhdlParser#verification_unit_list.
    def enterVerification_unit_list(self, ctx:vhdlParser.Verification_unit_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#verification_unit_list.
    def exitVerification_unit_list(self, ctx:vhdlParser.Verification_unit_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#disconnection_specification.
    def enterDisconnection_specification(self, ctx:vhdlParser.Disconnection_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#disconnection_specification.
    def exitDisconnection_specification(self, ctx:vhdlParser.Disconnection_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#guarded_signal_specification.
    def enterGuarded_signal_specification(self, ctx:vhdlParser.Guarded_signal_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#guarded_signal_specification.
    def exitGuarded_signal_specification(self, ctx:vhdlParser.Guarded_signal_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#signal_list.
    def enterSignal_list(self, ctx:vhdlParser.Signal_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#signal_list.
    def exitSignal_list(self, ctx:vhdlParser.Signal_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#attribute_designator.
    def enterAttribute_designator(self, ctx:vhdlParser.Attribute_designatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#attribute_designator.
    def exitAttribute_designator(self, ctx:vhdlParser.Attribute_designatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#external_name.
    def enterExternal_name(self, ctx:vhdlParser.External_nameContext):
        pass

    # Exit a parse tree produced by vhdlParser#external_name.
    def exitExternal_name(self, ctx:vhdlParser.External_nameContext):
        pass


    # Enter a parse tree produced by vhdlParser#external_pathname.
    def enterExternal_pathname(self, ctx:vhdlParser.External_pathnameContext):
        pass

    # Exit a parse tree produced by vhdlParser#external_pathname.
    def exitExternal_pathname(self, ctx:vhdlParser.External_pathnameContext):
        pass


    # Enter a parse tree produced by vhdlParser#package_pathname.
    def enterPackage_pathname(self, ctx:vhdlParser.Package_pathnameContext):
        pass

    # Exit a parse tree produced by vhdlParser#package_pathname.
    def exitPackage_pathname(self, ctx:vhdlParser.Package_pathnameContext):
        pass


    # Enter a parse tree produced by vhdlParser#absolute_pathname.
    def enterAbsolute_pathname(self, ctx:vhdlParser.Absolute_pathnameContext):
        pass

    # Exit a parse tree produced by vhdlParser#absolute_pathname.
    def exitAbsolute_pathname(self, ctx:vhdlParser.Absolute_pathnameContext):
        pass


    # Enter a parse tree produced by vhdlParser#relative_pathname.
    def enterRelative_pathname(self, ctx:vhdlParser.Relative_pathnameContext):
        pass

    # Exit a parse tree produced by vhdlParser#relative_pathname.
    def exitRelative_pathname(self, ctx:vhdlParser.Relative_pathnameContext):
        pass


    # Enter a parse tree produced by vhdlParser#partial_pathname.
    def enterPartial_pathname(self, ctx:vhdlParser.Partial_pathnameContext):
        pass

    # Exit a parse tree produced by vhdlParser#partial_pathname.
    def exitPartial_pathname(self, ctx:vhdlParser.Partial_pathnameContext):
        pass


    # Enter a parse tree produced by vhdlParser#pathname_element.
    def enterPathname_element(self, ctx:vhdlParser.Pathname_elementContext):
        pass

    # Exit a parse tree produced by vhdlParser#pathname_element.
    def exitPathname_element(self, ctx:vhdlParser.Pathname_elementContext):
        pass


    # Enter a parse tree produced by vhdlParser#expression.
    def enterExpression(self, ctx:vhdlParser.ExpressionContext):
        pass

    # Exit a parse tree produced by vhdlParser#expression.
    def exitExpression(self, ctx:vhdlParser.ExpressionContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_expression.
    def enterSimple_expression(self, ctx:vhdlParser.Simple_expressionContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_expression.
    def exitSimple_expression(self, ctx:vhdlParser.Simple_expressionContext):
        pass


    # Enter a parse tree produced by vhdlParser#primary.
    def enterPrimary(self, ctx:vhdlParser.PrimaryContext):
        pass

    # Exit a parse tree produced by vhdlParser#primary.
    def exitPrimary(self, ctx:vhdlParser.PrimaryContext):
        pass


    # Enter a parse tree produced by vhdlParser#logical_operator.
    def enterLogical_operator(self, ctx:vhdlParser.Logical_operatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#logical_operator.
    def exitLogical_operator(self, ctx:vhdlParser.Logical_operatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#relational_operator.
    def enterRelational_operator(self, ctx:vhdlParser.Relational_operatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#relational_operator.
    def exitRelational_operator(self, ctx:vhdlParser.Relational_operatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#shift_operator.
    def enterShift_operator(self, ctx:vhdlParser.Shift_operatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#shift_operator.
    def exitShift_operator(self, ctx:vhdlParser.Shift_operatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#adding_operator.
    def enterAdding_operator(self, ctx:vhdlParser.Adding_operatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#adding_operator.
    def exitAdding_operator(self, ctx:vhdlParser.Adding_operatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#sign.
    def enterSign(self, ctx:vhdlParser.SignContext):
        pass

    # Exit a parse tree produced by vhdlParser#sign.
    def exitSign(self, ctx:vhdlParser.SignContext):
        pass


    # Enter a parse tree produced by vhdlParser#multiplying_operator.
    def enterMultiplying_operator(self, ctx:vhdlParser.Multiplying_operatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#multiplying_operator.
    def exitMultiplying_operator(self, ctx:vhdlParser.Multiplying_operatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#miscellaneous_operator.
    def enterMiscellaneous_operator(self, ctx:vhdlParser.Miscellaneous_operatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#miscellaneous_operator.
    def exitMiscellaneous_operator(self, ctx:vhdlParser.Miscellaneous_operatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#numeric_literal.
    def enterNumeric_literal(self, ctx:vhdlParser.Numeric_literalContext):
        pass

    # Exit a parse tree produced by vhdlParser#numeric_literal.
    def exitNumeric_literal(self, ctx:vhdlParser.Numeric_literalContext):
        pass


    # Enter a parse tree produced by vhdlParser#physical_literal.
    def enterPhysical_literal(self, ctx:vhdlParser.Physical_literalContext):
        pass

    # Exit a parse tree produced by vhdlParser#physical_literal.
    def exitPhysical_literal(self, ctx:vhdlParser.Physical_literalContext):
        pass


    # Enter a parse tree produced by vhdlParser#aggregate.
    def enterAggregate(self, ctx:vhdlParser.AggregateContext):
        pass

    # Exit a parse tree produced by vhdlParser#aggregate.
    def exitAggregate(self, ctx:vhdlParser.AggregateContext):
        pass


    # Enter a parse tree produced by vhdlParser#element_association.
    def enterElement_association(self, ctx:vhdlParser.Element_associationContext):
        pass

    # Exit a parse tree produced by vhdlParser#element_association.
    def exitElement_association(self, ctx:vhdlParser.Element_associationContext):
        pass


    # Enter a parse tree produced by vhdlParser#choices.
    def enterChoices(self, ctx:vhdlParser.ChoicesContext):
        pass

    # Exit a parse tree produced by vhdlParser#choices.
    def exitChoices(self, ctx:vhdlParser.ChoicesContext):
        pass


    # Enter a parse tree produced by vhdlParser#choice.
    def enterChoice(self, ctx:vhdlParser.ChoiceContext):
        pass

    # Exit a parse tree produced by vhdlParser#choice.
    def exitChoice(self, ctx:vhdlParser.ChoiceContext):
        pass


    # Enter a parse tree produced by vhdlParser#qualified_expression.
    def enterQualified_expression(self, ctx:vhdlParser.Qualified_expressionContext):
        pass

    # Exit a parse tree produced by vhdlParser#qualified_expression.
    def exitQualified_expression(self, ctx:vhdlParser.Qualified_expressionContext):
        pass


    # Enter a parse tree produced by vhdlParser#allocator.
    def enterAllocator(self, ctx:vhdlParser.AllocatorContext):
        pass

    # Exit a parse tree produced by vhdlParser#allocator.
    def exitAllocator(self, ctx:vhdlParser.AllocatorContext):
        pass


    # Enter a parse tree produced by vhdlParser#sequence_of_statements.
    def enterSequence_of_statements(self, ctx:vhdlParser.Sequence_of_statementsContext):
        pass

    # Exit a parse tree produced by vhdlParser#sequence_of_statements.
    def exitSequence_of_statements(self, ctx:vhdlParser.Sequence_of_statementsContext):
        pass


    # Enter a parse tree produced by vhdlParser#sequential_statement.
    def enterSequential_statement(self, ctx:vhdlParser.Sequential_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#sequential_statement.
    def exitSequential_statement(self, ctx:vhdlParser.Sequential_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#wait_statement.
    def enterWait_statement(self, ctx:vhdlParser.Wait_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#wait_statement.
    def exitWait_statement(self, ctx:vhdlParser.Wait_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#sensitivity_clause.
    def enterSensitivity_clause(self, ctx:vhdlParser.Sensitivity_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#sensitivity_clause.
    def exitSensitivity_clause(self, ctx:vhdlParser.Sensitivity_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#sensitivity_list.
    def enterSensitivity_list(self, ctx:vhdlParser.Sensitivity_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#sensitivity_list.
    def exitSensitivity_list(self, ctx:vhdlParser.Sensitivity_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#condition_clause.
    def enterCondition_clause(self, ctx:vhdlParser.Condition_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#condition_clause.
    def exitCondition_clause(self, ctx:vhdlParser.Condition_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#condition.
    def enterCondition(self, ctx:vhdlParser.ConditionContext):
        pass

    # Exit a parse tree produced by vhdlParser#condition.
    def exitCondition(self, ctx:vhdlParser.ConditionContext):
        pass


    # Enter a parse tree produced by vhdlParser#timeout_clause.
    def enterTimeout_clause(self, ctx:vhdlParser.Timeout_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#timeout_clause.
    def exitTimeout_clause(self, ctx:vhdlParser.Timeout_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#assertion_statement.
    def enterAssertion_statement(self, ctx:vhdlParser.Assertion_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#assertion_statement.
    def exitAssertion_statement(self, ctx:vhdlParser.Assertion_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#assertion.
    def enterAssertion(self, ctx:vhdlParser.AssertionContext):
        pass

    # Exit a parse tree produced by vhdlParser#assertion.
    def exitAssertion(self, ctx:vhdlParser.AssertionContext):
        pass


    # Enter a parse tree produced by vhdlParser#report_statement.
    def enterReport_statement(self, ctx:vhdlParser.Report_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#report_statement.
    def exitReport_statement(self, ctx:vhdlParser.Report_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#signal_assignment_statement.
    def enterSignal_assignment_statement(self, ctx:vhdlParser.Signal_assignment_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#signal_assignment_statement.
    def exitSignal_assignment_statement(self, ctx:vhdlParser.Signal_assignment_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_signal_assignment.
    def enterSimple_signal_assignment(self, ctx:vhdlParser.Simple_signal_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_signal_assignment.
    def exitSimple_signal_assignment(self, ctx:vhdlParser.Simple_signal_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_waveform_assignment.
    def enterSimple_waveform_assignment(self, ctx:vhdlParser.Simple_waveform_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_waveform_assignment.
    def exitSimple_waveform_assignment(self, ctx:vhdlParser.Simple_waveform_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_force_assignment.
    def enterSimple_force_assignment(self, ctx:vhdlParser.Simple_force_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_force_assignment.
    def exitSimple_force_assignment(self, ctx:vhdlParser.Simple_force_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_release_assignment.
    def enterSimple_release_assignment(self, ctx:vhdlParser.Simple_release_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_release_assignment.
    def exitSimple_release_assignment(self, ctx:vhdlParser.Simple_release_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#force_mode.
    def enterForce_mode(self, ctx:vhdlParser.Force_modeContext):
        pass

    # Exit a parse tree produced by vhdlParser#force_mode.
    def exitForce_mode(self, ctx:vhdlParser.Force_modeContext):
        pass


    # Enter a parse tree produced by vhdlParser#delay_mechanism.
    def enterDelay_mechanism(self, ctx:vhdlParser.Delay_mechanismContext):
        pass

    # Exit a parse tree produced by vhdlParser#delay_mechanism.
    def exitDelay_mechanism(self, ctx:vhdlParser.Delay_mechanismContext):
        pass


    # Enter a parse tree produced by vhdlParser#target.
    def enterTarget(self, ctx:vhdlParser.TargetContext):
        pass

    # Exit a parse tree produced by vhdlParser#target.
    def exitTarget(self, ctx:vhdlParser.TargetContext):
        pass


    # Enter a parse tree produced by vhdlParser#waveform.
    def enterWaveform(self, ctx:vhdlParser.WaveformContext):
        pass

    # Exit a parse tree produced by vhdlParser#waveform.
    def exitWaveform(self, ctx:vhdlParser.WaveformContext):
        pass


    # Enter a parse tree produced by vhdlParser#waveform_element.
    def enterWaveform_element(self, ctx:vhdlParser.Waveform_elementContext):
        pass

    # Exit a parse tree produced by vhdlParser#waveform_element.
    def exitWaveform_element(self, ctx:vhdlParser.Waveform_elementContext):
        pass


    # Enter a parse tree produced by vhdlParser#conditional_signal_assignment.
    def enterConditional_signal_assignment(self, ctx:vhdlParser.Conditional_signal_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#conditional_signal_assignment.
    def exitConditional_signal_assignment(self, ctx:vhdlParser.Conditional_signal_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#conditional_waveform_assignment.
    def enterConditional_waveform_assignment(self, ctx:vhdlParser.Conditional_waveform_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#conditional_waveform_assignment.
    def exitConditional_waveform_assignment(self, ctx:vhdlParser.Conditional_waveform_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#conditional_waveforms.
    def enterConditional_waveforms(self, ctx:vhdlParser.Conditional_waveformsContext):
        pass

    # Exit a parse tree produced by vhdlParser#conditional_waveforms.
    def exitConditional_waveforms(self, ctx:vhdlParser.Conditional_waveformsContext):
        pass


    # Enter a parse tree produced by vhdlParser#conditional_force_assignment.
    def enterConditional_force_assignment(self, ctx:vhdlParser.Conditional_force_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#conditional_force_assignment.
    def exitConditional_force_assignment(self, ctx:vhdlParser.Conditional_force_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#conditional_expressions.
    def enterConditional_expressions(self, ctx:vhdlParser.Conditional_expressionsContext):
        pass

    # Exit a parse tree produced by vhdlParser#conditional_expressions.
    def exitConditional_expressions(self, ctx:vhdlParser.Conditional_expressionsContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_signal_assignment.
    def enterSelected_signal_assignment(self, ctx:vhdlParser.Selected_signal_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_signal_assignment.
    def exitSelected_signal_assignment(self, ctx:vhdlParser.Selected_signal_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_waveform_assignment.
    def enterSelected_waveform_assignment(self, ctx:vhdlParser.Selected_waveform_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_waveform_assignment.
    def exitSelected_waveform_assignment(self, ctx:vhdlParser.Selected_waveform_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_waveforms.
    def enterSelected_waveforms(self, ctx:vhdlParser.Selected_waveformsContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_waveforms.
    def exitSelected_waveforms(self, ctx:vhdlParser.Selected_waveformsContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_force_assignment.
    def enterSelected_force_assignment(self, ctx:vhdlParser.Selected_force_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_force_assignment.
    def exitSelected_force_assignment(self, ctx:vhdlParser.Selected_force_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_expressions.
    def enterSelected_expressions(self, ctx:vhdlParser.Selected_expressionsContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_expressions.
    def exitSelected_expressions(self, ctx:vhdlParser.Selected_expressionsContext):
        pass


    # Enter a parse tree produced by vhdlParser#variable_assignment_statement.
    def enterVariable_assignment_statement(self, ctx:vhdlParser.Variable_assignment_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#variable_assignment_statement.
    def exitVariable_assignment_statement(self, ctx:vhdlParser.Variable_assignment_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#simple_variable_assignment.
    def enterSimple_variable_assignment(self, ctx:vhdlParser.Simple_variable_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#simple_variable_assignment.
    def exitSimple_variable_assignment(self, ctx:vhdlParser.Simple_variable_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#conditional_variable_assignment.
    def enterConditional_variable_assignment(self, ctx:vhdlParser.Conditional_variable_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#conditional_variable_assignment.
    def exitConditional_variable_assignment(self, ctx:vhdlParser.Conditional_variable_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#selected_variable_assignment.
    def enterSelected_variable_assignment(self, ctx:vhdlParser.Selected_variable_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#selected_variable_assignment.
    def exitSelected_variable_assignment(self, ctx:vhdlParser.Selected_variable_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#procedure_call_statement.
    def enterProcedure_call_statement(self, ctx:vhdlParser.Procedure_call_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#procedure_call_statement.
    def exitProcedure_call_statement(self, ctx:vhdlParser.Procedure_call_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#procedure_call.
    def enterProcedure_call(self, ctx:vhdlParser.Procedure_callContext):
        pass

    # Exit a parse tree produced by vhdlParser#procedure_call.
    def exitProcedure_call(self, ctx:vhdlParser.Procedure_callContext):
        pass


    # Enter a parse tree produced by vhdlParser#if_statement.
    def enterIf_statement(self, ctx:vhdlParser.If_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#if_statement.
    def exitIf_statement(self, ctx:vhdlParser.If_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#case_statement.
    def enterCase_statement(self, ctx:vhdlParser.Case_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#case_statement.
    def exitCase_statement(self, ctx:vhdlParser.Case_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#case_statement_alternative.
    def enterCase_statement_alternative(self, ctx:vhdlParser.Case_statement_alternativeContext):
        pass

    # Exit a parse tree produced by vhdlParser#case_statement_alternative.
    def exitCase_statement_alternative(self, ctx:vhdlParser.Case_statement_alternativeContext):
        pass


    # Enter a parse tree produced by vhdlParser#loop_statement.
    def enterLoop_statement(self, ctx:vhdlParser.Loop_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#loop_statement.
    def exitLoop_statement(self, ctx:vhdlParser.Loop_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#iteration_scheme.
    def enterIteration_scheme(self, ctx:vhdlParser.Iteration_schemeContext):
        pass

    # Exit a parse tree produced by vhdlParser#iteration_scheme.
    def exitIteration_scheme(self, ctx:vhdlParser.Iteration_schemeContext):
        pass


    # Enter a parse tree produced by vhdlParser#parameter_specification.
    def enterParameter_specification(self, ctx:vhdlParser.Parameter_specificationContext):
        pass

    # Exit a parse tree produced by vhdlParser#parameter_specification.
    def exitParameter_specification(self, ctx:vhdlParser.Parameter_specificationContext):
        pass


    # Enter a parse tree produced by vhdlParser#next_statement.
    def enterNext_statement(self, ctx:vhdlParser.Next_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#next_statement.
    def exitNext_statement(self, ctx:vhdlParser.Next_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#exit_statement.
    def enterExit_statement(self, ctx:vhdlParser.Exit_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#exit_statement.
    def exitExit_statement(self, ctx:vhdlParser.Exit_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#return_statement.
    def enterReturn_statement(self, ctx:vhdlParser.Return_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#return_statement.
    def exitReturn_statement(self, ctx:vhdlParser.Return_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#null_statement.
    def enterNull_statement(self, ctx:vhdlParser.Null_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#null_statement.
    def exitNull_statement(self, ctx:vhdlParser.Null_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_statement_with_optional_label.
    def enterConcurrent_statement_with_optional_label(self, ctx:vhdlParser.Concurrent_statement_with_optional_labelContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_statement_with_optional_label.
    def exitConcurrent_statement_with_optional_label(self, ctx:vhdlParser.Concurrent_statement_with_optional_labelContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_statement.
    def enterConcurrent_statement(self, ctx:vhdlParser.Concurrent_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_statement.
    def exitConcurrent_statement(self, ctx:vhdlParser.Concurrent_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#block_statement.
    def enterBlock_statement(self, ctx:vhdlParser.Block_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#block_statement.
    def exitBlock_statement(self, ctx:vhdlParser.Block_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#block_header.
    def enterBlock_header(self, ctx:vhdlParser.Block_headerContext):
        pass

    # Exit a parse tree produced by vhdlParser#block_header.
    def exitBlock_header(self, ctx:vhdlParser.Block_headerContext):
        pass


    # Enter a parse tree produced by vhdlParser#process_statement.
    def enterProcess_statement(self, ctx:vhdlParser.Process_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#process_statement.
    def exitProcess_statement(self, ctx:vhdlParser.Process_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#process_sensitivity_list.
    def enterProcess_sensitivity_list(self, ctx:vhdlParser.Process_sensitivity_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#process_sensitivity_list.
    def exitProcess_sensitivity_list(self, ctx:vhdlParser.Process_sensitivity_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#process_or_package_declarative_item.
    def enterProcess_or_package_declarative_item(self, ctx:vhdlParser.Process_or_package_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#process_or_package_declarative_item.
    def exitProcess_or_package_declarative_item(self, ctx:vhdlParser.Process_or_package_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#process_declarative_item.
    def enterProcess_declarative_item(self, ctx:vhdlParser.Process_declarative_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#process_declarative_item.
    def exitProcess_declarative_item(self, ctx:vhdlParser.Process_declarative_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_procedure_call_statement.
    def enterConcurrent_procedure_call_statement(self, ctx:vhdlParser.Concurrent_procedure_call_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_procedure_call_statement.
    def exitConcurrent_procedure_call_statement(self, ctx:vhdlParser.Concurrent_procedure_call_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_assertion_statement.
    def enterConcurrent_assertion_statement(self, ctx:vhdlParser.Concurrent_assertion_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_assertion_statement.
    def exitConcurrent_assertion_statement(self, ctx:vhdlParser.Concurrent_assertion_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_signal_assignment_statement.
    def enterConcurrent_signal_assignment_statement(self, ctx:vhdlParser.Concurrent_signal_assignment_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_signal_assignment_statement.
    def exitConcurrent_signal_assignment_statement(self, ctx:vhdlParser.Concurrent_signal_assignment_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_signal_assignment_any.
    def enterConcurrent_signal_assignment_any(self, ctx:vhdlParser.Concurrent_signal_assignment_anyContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_signal_assignment_any.
    def exitConcurrent_signal_assignment_any(self, ctx:vhdlParser.Concurrent_signal_assignment_anyContext):
        pass


    # Enter a parse tree produced by vhdlParser#concurrent_selected_signal_assignment.
    def enterConcurrent_selected_signal_assignment(self, ctx:vhdlParser.Concurrent_selected_signal_assignmentContext):
        pass

    # Exit a parse tree produced by vhdlParser#concurrent_selected_signal_assignment.
    def exitConcurrent_selected_signal_assignment(self, ctx:vhdlParser.Concurrent_selected_signal_assignmentContext):
        pass


    # Enter a parse tree produced by vhdlParser#component_instantiation_statement.
    def enterComponent_instantiation_statement(self, ctx:vhdlParser.Component_instantiation_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#component_instantiation_statement.
    def exitComponent_instantiation_statement(self, ctx:vhdlParser.Component_instantiation_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#instantiated_unit.
    def enterInstantiated_unit(self, ctx:vhdlParser.Instantiated_unitContext):
        pass

    # Exit a parse tree produced by vhdlParser#instantiated_unit.
    def exitInstantiated_unit(self, ctx:vhdlParser.Instantiated_unitContext):
        pass


    # Enter a parse tree produced by vhdlParser#generate_statement.
    def enterGenerate_statement(self, ctx:vhdlParser.Generate_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#generate_statement.
    def exitGenerate_statement(self, ctx:vhdlParser.Generate_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#for_generate_statement.
    def enterFor_generate_statement(self, ctx:vhdlParser.For_generate_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#for_generate_statement.
    def exitFor_generate_statement(self, ctx:vhdlParser.For_generate_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#if_generate_statement.
    def enterIf_generate_statement(self, ctx:vhdlParser.If_generate_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#if_generate_statement.
    def exitIf_generate_statement(self, ctx:vhdlParser.If_generate_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#case_generate_statement.
    def enterCase_generate_statement(self, ctx:vhdlParser.Case_generate_statementContext):
        pass

    # Exit a parse tree produced by vhdlParser#case_generate_statement.
    def exitCase_generate_statement(self, ctx:vhdlParser.Case_generate_statementContext):
        pass


    # Enter a parse tree produced by vhdlParser#case_generate_alternative.
    def enterCase_generate_alternative(self, ctx:vhdlParser.Case_generate_alternativeContext):
        pass

    # Exit a parse tree produced by vhdlParser#case_generate_alternative.
    def exitCase_generate_alternative(self, ctx:vhdlParser.Case_generate_alternativeContext):
        pass


    # Enter a parse tree produced by vhdlParser#generate_statement_body_with_begin_end.
    def enterGenerate_statement_body_with_begin_end(self, ctx:vhdlParser.Generate_statement_body_with_begin_endContext):
        pass

    # Exit a parse tree produced by vhdlParser#generate_statement_body_with_begin_end.
    def exitGenerate_statement_body_with_begin_end(self, ctx:vhdlParser.Generate_statement_body_with_begin_endContext):
        pass


    # Enter a parse tree produced by vhdlParser#generate_statement_body.
    def enterGenerate_statement_body(self, ctx:vhdlParser.Generate_statement_bodyContext):
        pass

    # Exit a parse tree produced by vhdlParser#generate_statement_body.
    def exitGenerate_statement_body(self, ctx:vhdlParser.Generate_statement_bodyContext):
        pass


    # Enter a parse tree produced by vhdlParser#label.
    def enterLabel(self, ctx:vhdlParser.LabelContext):
        pass

    # Exit a parse tree produced by vhdlParser#label.
    def exitLabel(self, ctx:vhdlParser.LabelContext):
        pass


    # Enter a parse tree produced by vhdlParser#use_clause.
    def enterUse_clause(self, ctx:vhdlParser.Use_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#use_clause.
    def exitUse_clause(self, ctx:vhdlParser.Use_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#design_file.
    def enterDesign_file(self, ctx:vhdlParser.Design_fileContext):
        pass

    # Exit a parse tree produced by vhdlParser#design_file.
    def exitDesign_file(self, ctx:vhdlParser.Design_fileContext):
        pass


    # Enter a parse tree produced by vhdlParser#design_unit.
    def enterDesign_unit(self, ctx:vhdlParser.Design_unitContext):
        pass

    # Exit a parse tree produced by vhdlParser#design_unit.
    def exitDesign_unit(self, ctx:vhdlParser.Design_unitContext):
        pass


    # Enter a parse tree produced by vhdlParser#library_unit.
    def enterLibrary_unit(self, ctx:vhdlParser.Library_unitContext):
        pass

    # Exit a parse tree produced by vhdlParser#library_unit.
    def exitLibrary_unit(self, ctx:vhdlParser.Library_unitContext):
        pass


    # Enter a parse tree produced by vhdlParser#primary_unit.
    def enterPrimary_unit(self, ctx:vhdlParser.Primary_unitContext):
        pass

    # Exit a parse tree produced by vhdlParser#primary_unit.
    def exitPrimary_unit(self, ctx:vhdlParser.Primary_unitContext):
        pass


    # Enter a parse tree produced by vhdlParser#secondary_unit.
    def enterSecondary_unit(self, ctx:vhdlParser.Secondary_unitContext):
        pass

    # Exit a parse tree produced by vhdlParser#secondary_unit.
    def exitSecondary_unit(self, ctx:vhdlParser.Secondary_unitContext):
        pass


    # Enter a parse tree produced by vhdlParser#library_clause.
    def enterLibrary_clause(self, ctx:vhdlParser.Library_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#library_clause.
    def exitLibrary_clause(self, ctx:vhdlParser.Library_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#logical_name_list.
    def enterLogical_name_list(self, ctx:vhdlParser.Logical_name_listContext):
        pass

    # Exit a parse tree produced by vhdlParser#logical_name_list.
    def exitLogical_name_list(self, ctx:vhdlParser.Logical_name_listContext):
        pass


    # Enter a parse tree produced by vhdlParser#context_declaration.
    def enterContext_declaration(self, ctx:vhdlParser.Context_declarationContext):
        pass

    # Exit a parse tree produced by vhdlParser#context_declaration.
    def exitContext_declaration(self, ctx:vhdlParser.Context_declarationContext):
        pass


    # Enter a parse tree produced by vhdlParser#context_clause.
    def enterContext_clause(self, ctx:vhdlParser.Context_clauseContext):
        pass

    # Exit a parse tree produced by vhdlParser#context_clause.
    def exitContext_clause(self, ctx:vhdlParser.Context_clauseContext):
        pass


    # Enter a parse tree produced by vhdlParser#context_item.
    def enterContext_item(self, ctx:vhdlParser.Context_itemContext):
        pass

    # Exit a parse tree produced by vhdlParser#context_item.
    def exitContext_item(self, ctx:vhdlParser.Context_itemContext):
        pass


    # Enter a parse tree produced by vhdlParser#context_reference.
    def enterContext_reference(self, ctx:vhdlParser.Context_referenceContext):
        pass

    # Exit a parse tree produced by vhdlParser#context_reference.
    def exitContext_reference(self, ctx:vhdlParser.Context_referenceContext):
        pass


    # Enter a parse tree produced by vhdlParser#identifier.
    def enterIdentifier(self, ctx:vhdlParser.IdentifierContext):
        pass

    # Exit a parse tree produced by vhdlParser#identifier.
    def exitIdentifier(self, ctx:vhdlParser.IdentifierContext):
        pass



del vhdlParser


from pathlib import Path
from typing import Dict, Union
import yaml


class Configuration:
    __config_dict = {
        # Dovado Working Dir
        # This directory will be created in the same directory
        # in which the "dovado" command is executed
        "WORK_DIR": "dovado_work/",
        # Directory holding tcl scripts
        "TCL_DIR": "tcl/",
        # Directory holding xdc files
        "XDC_DIR": "xdc/",
        # Directory holding vhdl files
        "VHDL_DIR": "vhdl/",
        # Directory holding verilog files
        "VERILOG_DIR": "verilog/",
        # Constraint file for setting master clock frequency
        # with blank clock to be filled
        "CONSTRAINT_FRAME": "constraint_frame.xdc",
        # Constraint file with clock filled
        "CONSTRAINT": "constraint.xdc",
        # TCL script with blank fields to be filled
        # with user input in order to evaluate vhdl source until synthesis
        "SYNTHESIS_FRAME": "synthesis_frame.tcl",
        # TCL script with all fields filled with user input until synthesis
        "SYNTHESIS": "synthesis.tcl",
        # TCL script with blank fields to be filled
        # with user input in order to evaluate vhdl source
        "IMPLEMENTATION_FRAME": "implementation_frame.tcl",
        # TCL script with all fields filled with user input
        "IMPLEMENTATION": "implementation.tcl",
        # Vhdl file with fields to be filled for boxing
        "VHDL_BOX_FRAME": "box_frame.vhd",
        # Vhdl file with all fields filled
        "VHDL_BOX": "box.vhd",
        # Verilog file with fields to be filled for boxing
        "VERILOG_BOX_FRAME": "box_frame.sv",
        # Verilog file with all fields filled
        "VERILOG_BOX": "box.sv",
        # Placeholder inside the two above files
        # to be swapped with user input
        "PLACEHOLDER": "____",
        # Output of vivado call (reports and checkpoints)
        "VIVADO_OUTPUT_DIR": "vivado_out/",
        # After Synthesis Utilisation Report Name
        "SYNTHESIS_UTILISATION": "post_synth_util.xml",
        # After Implementation Utilisation Report Name
        "IMPLEMENTATION_UTILISATION": "post_impl_util.xml",
        # After Synthesis Timing (setup) Report Name
        "SYNTHESIS_TIMING": "post_synth_setup_timing.rpt",
        # After Implementation Timing (setup) Report Name
        "IMPLEMENTATION_TIMING": "post_impl_setup_timing.rpt",
        # Maximum integer value considered for RTL parameters
        "INTEGER_HIGH": 2147483647,
        # Run time set as a constraint for the genetic algorithm, format "hh:mm:ss"
        "GENETIC_RUN_TIME": "04:00:00",
    }

    def __init__(self):
        config_path = Path("dovado.yaml")
        self.config: Dict[str, Union[str, int]] = yaml.safe_load(
            config_path.open()
        ) if config_path.is_file() else self.__config_dict

    def get_config(self, config_name: str):
        if config_name in self.config:
            return self.config[config_name]
        else:
            return self.__config_dict[config_name]
